@@ -11,7 +11,9 @@ TAopt <- function(OF, algo = list(), ...) {
                   stepUp = 0L,
                   scale = 1,
                   storeF = TRUE,
-                  storeSolutions = FALSE)
+                  storeSolutions = FALSE,
+                  classify = FALSE,
+                  OF.target = NULL)
 
     checkList(algo, algoD)
     algoD[names(algo)] <- algo
@@ -22,12 +24,13 @@ TAopt <- function(OF, algo = list(), ...) {
 
     ## user *must* specify the following
     if (is.null(algoD$neighbour))
-        stop("specify a neighbourhood function 'algo$neighbour'")
+        stop("specify a neighbourhood function ", sQuote("algo$neighbour"))
     if (!is.function(algoD$neighbour))
-        stop("'algo$neighbour' must be a function")
+        stop(sQuote("algo$neighbour"), " must be a function")
     if (is.null(algoD$x0))
-        stop("specify start solution 'algo$x0'")
-    if (is.function(algoD$x0)) ## evaluate x0 if function
+        stop("specify start solution ", sQuote("algo$x0"))
+
+    if (is.function(algoD$x0)) 
         x0 <- algoD$x0() else x0 <- eval(algoD$x0)
 
     OF1 <- function(x)
@@ -35,6 +38,8 @@ TAopt <- function(OF, algo = list(), ...) {
     N1 <- function(x)
         algoD$neighbour(x, ...)
 
+    target.reached <- FALSE
+    
     printDetail <- algoD$printDetail
     printBar <- algoD$printBar
     if (printBar && printDetail > 1)
@@ -43,10 +48,10 @@ TAopt <- function(OF, algo = list(), ...) {
         cat("\nThreshold Accepting.\n")
 
 
-    nT <- makeInteger(algoD$nT, "'algo$nT'")
-    nS <- makeInteger(algoD$nS, "'algo$nS'")
-    nD <- makeInteger(algoD$nD, "'algo$nD'")
-    stepUp <- makeInteger(algoD$stepUp, "'algo$stepUp'", 0L)
+    nT <- makeInteger(algoD$nT, "algo$nT")
+    nS <- makeInteger(algoD$nS, "algo$nS")
+    nD <- makeInteger(algoD$nD, "algo$nD")
+    stepUp <- makeInteger(algoD$stepUp, "algo$stepUp", 0L)
     niter <- nS * nT * (stepUp+1L)
 
     ## compute thresholds
@@ -80,7 +85,7 @@ TAopt <- function(OF, algo = list(), ...) {
             if (any(is.na(diffF)))
                 stop("objective function evaluated to NA")
             vT <- quantile(diffF, vT, na.rm = FALSE)
-            vT[nT] <- 0 ### set last threshold to zero
+            vT[nT] <- 0  ## set last threshold to zero
             if (printBar)
                 close(whatGen)
             if (printDetail) {
@@ -131,11 +136,10 @@ TAopt <- function(OF, algo = list(), ...) {
         whatGen <- txtProgressBar(min = 1, max = niter, style = 3,
                                   getOption("width")*0.9)
 
-    ## main algorithm
     counter <- 0L
     for (t in seq_len(nT)) {
         for (s in seq_len(nS)) {
-            ## number of iterations
+            ## counter = total number of iterations
             counter <- counter + 1L
 
             xn <- N1(xc)
@@ -164,7 +168,6 @@ TAopt <- function(OF, algo = list(), ...) {
                 xlist[[c(2L, counter)]] <- xc
             }
 
-            ## print info
             if (printDetail > 1) {
                 if (counter %% printDetail == 0L) {
                     cat("Best solution (iteration ", counter,
@@ -173,8 +176,21 @@ TAopt <- function(OF, algo = list(), ...) {
                     flush.console()
                 }
             }
-
+            
+            ## check stopif value
+            if (!is.null(algo$OF.target) && xbestF <= algo$OF.target) {
+                if (printDetail) {
+                    cat("Target value (", prettyNum(algo$OF.target), ") ",
+                        "for objective function reached: ",
+                        prettyNum(xbestF), "\n", sep = "")
+                    flush.console()
+                    target.reached  <- TRUE
+                }
+                break    
+            }
         }
+        if (target.reached)
+            break
     }
     if (printDetail)
         cat("Finished.\nBest solution overall: ",
@@ -182,10 +198,12 @@ TAopt <- function(OF, algo = list(), ...) {
     if (printBar)
         close(whatGen)
 
-    ## return best solution
-    list(xbest = xbest, OFvalue = xbestF,
-         Fmat = Fmat, xlist = xlist, vT = vT,
-         initial.state = state)
+    ans <- list(xbest = xbest, OFvalue = xbestF,
+                Fmat = Fmat, xlist = xlist, vT = vT,
+                initial.state = state)
+    if (algoD$classify)
+        class(ans) <- "TAopt"
+    ans
 }
 
 TA.info <- function(n = 0L) {
@@ -194,6 +212,7 @@ TA.info <- function(n = 0L) {
     threshold <- NA
     iteration <- NA
     iteration.sampling <- NA
+    xbest <- NA
     if (exists("i", envir = e, inherits = FALSE))
         step <- get("i", envir = e, inherits = FALSE)
     if (exists("s", envir = e, inherits = FALSE))
@@ -202,23 +221,55 @@ TA.info <- function(n = 0L) {
         threshold <- get("t", envir = e, inherits = FALSE)
     if (exists("counter", envir = e, inherits = FALSE))
         iteration <- get("counter", envir = e, inherits = FALSE)
+    if (exists("xbest", envir = e, inherits = FALSE))
+        xbest <- get("xbest", envir = e, inherits = FALSE)
     list(iteration.sampling = iteration.sampling,
          iteration = iteration,
          step = step,
-         threshold = threshold)
+         threshold = threshold,
+         xbest = if (is.list(xbest)) list(xbest) else xbest)
 }
 
 
-                                        # METHODS (not exported)
+                                        # METHODS
 
 print.TAopt <- function(x, ...) {
-    cat("Threshold Accepting.\n")
-    cat(".. objective function value of solution: ", x$OFvalue, "\n")
+    cat("Threshold Accepting\n")
+    cat("_ final objective-function value: ", x$OFvalue, "\n")
+    invisible(x)
 }
 
-plot.TAopt <- function(x, y, ...) {
-    plot(x$vT, xlab = "Threshold", ylab = "Values")
-    dev.new()
+plot.TAopt <- function(x, y, plot.type = "interactive", ...) {
+    if (plot.type == "interactive") {
+        dev.new(title = "TAopt: Threshold sequence")
+        defaults <- list(x    = x$vT,
+                         xlab = "Threshold",
+                         ylab = "Values",
+                         main = "TAopt: Threshold Sequence",
+                         type = "b")
+        do.call("plot", defaults)
+        if (!is.null(x$Fmat)) {
+            dev.new(title = "TAopt: Objective function values")
+            defaults <- list(x    = x$Fmat[,1L],
+                             xlab = "Iteration",
+                             ylab = "Objective function value",
+                             main = "TAopt: Objective function values",
+                             type = "l",
+                             col  = grey(0.6))
+            do.call("plot", defaults, ...)
+
+            defaults$x <- x$Fmat[,2L]
+            defaults$col <- grey(0.2)
+            do.call("lines", defaults, ...)
+
+            defaults$x <- cummin(x$Fmat[,2L])
+            defaults$col <- "blue"
+            do.call("lines", defaults, ...)
+        }
+    } else {
+        .NotYetUsed("plot.type")
+    }
+    invisible()
 }
 
 
