@@ -1,11 +1,11 @@
-repairMatrix <- function(C) {
+repairMatrix <- function(C, eps = 0) {
     ## compute eigenvectors/-values
     E <- eigen(C, symmetric = TRUE)   
     V <- E$vectors
     D <- E$values
     
-    ## replace negative eigenvalues by zero
-    D <- pmax(D, 0)
+    ## replace *negative* eigenvalues by eps
+    D <- pmax(D, eps)
     
     ## reconstruct correlation matrix
     BB <- V %*% diag(D) %*% t(V)
@@ -13,7 +13,6 @@ repairMatrix <- function(C) {
     ## rescale correlation matrix
     T <- 1/sqrt(diag(BB))
     TT <- outer(T,T)
-    C <- BB * TT
-    C
+    BB * TT
 }
 
